==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/hotkey/translations/hotkey_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Keisti nuorodą</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>Paspauskite klavišų kombinaciją, kurią norite priskirti</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="32"/>
        <source>Global Hotkey Plugin</source>
        <translation>Global Hotkey klavišų įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="58"/>
        <source>About Global Hotkey Plugin</source>
        <translation>Apie Global Hotkey įskiepį</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="59"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp Global Hotkey įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="60"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>This plugin adds support for multimedia keys or global key combinations</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="61"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Pause</source>
        <translation>Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>Play/Pause</source>
        <translation>Groti/Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>Next</source>
        <translation>Sekantis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Previous</source>
        <translation>Ankstesnis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Show/Hide</source>
        <translation>Rodyti/Slėpti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Volume +</source>
        <translation>Garsas +</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Volume -</source>
        <translation>Garsas -</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Forward 5 seconds</source>
        <translation>Į priekį 5 sekundėmis </translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Rewind 5 seconds</source>
        <translation>Persukti 5 sekundes</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Jump to track</source>
        <translation>Pereiti prie takelio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Key sequence &apos;%1&apos; is already used</source>
        <translation>Klavišo kombinacija &apos;%1&apos; jau naudojama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Global Hotkey nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Nuoroda</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Ištrinti</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/hotkey/translations/hotkey_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Keisti nuorodą</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>Paspauskite klavišų kombinaciją, kurią norite priskirti</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="31"/>
        <source>Global Hotkey Plugin</source>
        <translation>Global Hotkey klavišų įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>About Global Hotkey Plugin</source>
        <translation>Apie Global Hotkey įskiepį</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp Global Hotkey įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>This plugin adds support for multimedia keys or global key combinations</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Pause</source>
        <translation>Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>Play/Pause</source>
        <translation>Groti/Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>Next</source>
        <translation>Sekantis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Previous</source>
        <translation>Ankstesnis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Show/Hide</source>
        <translation>Rodyti/Slėpti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Volume +</source>
        <translation>Garsas +</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Volume -</source>
        <translation>Garsas -</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Forward 5 seconds</source>
        <translation>Į priekį 5 sekundėmis </translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Rewind 5 seconds</source>
        <translation>Persukti 5 sekundes</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Jump to track</source>
        <translation>Pereiti prie takelio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Key sequence &apos;%1&apos; is already used</source>
        <translation>Klavišo kombinacija &apos;%1&apos; jau naudojama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Global Hotkey nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Nuoroda</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Ištrinti</translation>
    </message>
</context>
</TS>
